@@ -4,8 +4,8 @@
 prefix=/opt/gnome
 exec_prefix=${prefix}
 
-orbit_includes="`/usr/bin/orbit-config --cflags server`"
-orbit_libs_output="`/usr/bin/orbit-config --use-service=name --libs server`"
+orbit_includes="`/opt/gnome/bin/orbit-config --cflags server`"
+orbit_libs_output="`/opt/gnome/bin/orbit-config --use-service=name --libs server`"
 
 orbit_libdirs=
 orbit_libs=
@@ -19,5 +19,5 @@ done
 OAF_LIBDIR="-L${exec_prefix}/lib $orbit_libdirs"
 OAF_LIBS="-loaf $orbit_libs"
 OAF_INCLUDEDIR="-I${prefix}/include $orbit_includes"
-MODULE_VERSION="oaf-0.6.9"
+MODULE_VERSION="oaf-0.6.10"
 
